IGNORED_BRANCHES = {"gh-pages"}

SUPPORTED_FILE_TYPES = {
    ".txt",
    ".md",
    ".py",
    ".c",
    ".cc",
    ".cpp",
    ".cxx",
    ".h",
    ".hpp",
    ".ts",
    ".js",
    ".tsx",
    ".jsx",
    ".html",
    ".go",
    ".java",
    ".php",
    ".rb",
}
